@@ -18,7 +18,7 @@ enum {
   SPVM_BASIC_TYPE_C_ID_DOUBLE,
   SPVM_BASIC_TYPE_C_ID_STRING,
   SPVM_BASIC_TYPE_C_ID_ANY_OBJECT,
-  SPVM_BASIC_TYPE_C_ID_OARRAY,
+  SPVM_BASIC_TYPE_C_ID_ELEMENT,
   SPVM_BASIC_TYPE_C_ID_BYTE_OBJECT,
   SPVM_BASIC_TYPE_C_ID_SHORT_OBJECT,
   SPVM_BASIC_TYPE_C_ID_INT_OBJECT,
