@@ -1,18 +1,13 @@
-// Copyright (c) 2023 Yuki Kimoto
-// MIT License
-
 #ifndef SPVM_RUNTIME_H
 #define SPVM_RUNTIME_H
 
 #include "spvm_typedecl.h"
 
-struct spvm_runtime {
-  // SPVM 32bit codes
-  int32_t* runtime_codes;
+SPVM_RUNTIME* SPVM_RUNTIME_new();
 
-  // SPVM 32bit codes
-  int32_t runtime_codes_length;
-  
+void SPVM_RUNTIME_free(SPVM_RUNTIME* runtime);
+
+struct spvm_runtime {
   // Allocator
   SPVM_ALLOCATOR* allocator;
   
@@ -23,16 +18,16 @@ struct spvm_runtime {
   int32_t opcodes_length;
 
   // String buffer
-  const char* constant_strings_buffer;
+  const char* string_buffer;
 
   // String buffer length
-  int32_t constant_strings_buffer_length;
+  int32_t string_buffer_length;
 
   // Strings
-  SPVM_RUNTIME_CONSTANT_STRING* constant_strings;
+  SPVM_RUNTIME_STRING* strings;
 
   // The length of strings
-  int32_t constant_strings_length;
+  int32_t strings_length;
   
   // Basic types
   SPVM_RUNTIME_BASIC_TYPE* basic_types;
@@ -68,13 +63,7 @@ struct spvm_runtime {
   int32_t* arg_type_ids;
 
   // The length of methods
-  int32_t arg_types_length;
-
-  // Anon nethod ids
-  int32_t* anon_method_method_ids;
-
-  // The length of anon methods
-  int32_t anon_methods_length;
+  int32_t arg_type_ids_length;
 
   // Class variables
   SPVM_RUNTIME_CLASS_VAR* class_vars;
@@ -89,23 +78,16 @@ struct spvm_runtime {
   int32_t fields_length;
   
   // String symtable
-  SPVM_HASH* constant_string_symtable;
+  SPVM_HASH* string_symtable;
 
   // Runtime Basic type symbol table
   SPVM_HASH* basic_type_symtable;
 
   // Runtime class symbol table
   SPVM_HASH* class_symtable;
+
 };
 
-SPVM_RUNTIME* SPVM_RUNTIME_new();
-
-void SPVM_RUNTIME_free(SPVM_RUNTIME* runtime);
-
-void SPVM_RUNTIME_build_symbol_table(SPVM_RUNTIME* runtime);
-
-SPVM_ALLOCATOR* SPVM_RUNTIME_get_allocator(SPVM_RUNTIME* runtime);
-
-void SPVM_RUNTIME_build(SPVM_RUNTIME* runtime, int32_t* runtime_codes);
+void SPVM_RUNTIME_prepare(SPVM_RUNTIME* runtime);
 
 #endif
